Struct LiquidationServiceClient
pub struct LiquidationServiceClient<T> { /* private fields */ }Expand description
LiquidationService defines the gRPC service used by liquidation daemon.
Implementations
impl LiquidationServiceClient<Channel>
impl LiquidationServiceClient<Channel>
impl<T> LiquidationServiceClient<T>
impl<T> LiquidationServiceClient<T>
pub fn new(inner: T) -> LiquidationServiceClient<T>
pub fn with_origin(inner: T, origin: Uri) -> LiquidationServiceClient<T>
pub fn with_interceptor<F>( inner: T, interceptor: F, ) -> LiquidationServiceClient<InterceptedService<T, F>>
pub fn send_compressed(
self,
encoding: CompressionEncoding,
) -> LiquidationServiceClient<T>
pub fn send_compressed( self, encoding: CompressionEncoding, ) -> LiquidationServiceClient<T>
Compress requests with the given encoding.
This requires the server to support it otherwise it might respond with an error.
pub fn accept_compressed(
self,
encoding: CompressionEncoding,
) -> LiquidationServiceClient<T>
pub fn accept_compressed( self, encoding: CompressionEncoding, ) -> LiquidationServiceClient<T>
Enable decompressing responses.
pub fn max_decoding_message_size(
self,
limit: usize,
) -> LiquidationServiceClient<T>
pub fn max_decoding_message_size( self, limit: usize, ) -> LiquidationServiceClient<T>
Limits the maximum size of a decoded message.
Default: 4MB
pub fn max_encoding_message_size(
self,
limit: usize,
) -> LiquidationServiceClient<T>
pub fn max_encoding_message_size( self, limit: usize, ) -> LiquidationServiceClient<T>
Limits the maximum size of an encoded message.
Default: usize::MAX
pub async fn liquidate_subaccounts(
&mut self,
request: impl IntoRequest<LiquidateSubaccountsRequest>,
) -> Result<Response<LiquidateSubaccountsResponse>, Status>
pub async fn liquidate_subaccounts( &mut self, request: impl IntoRequest<LiquidateSubaccountsRequest>, ) -> Result<Response<LiquidateSubaccountsResponse>, Status>
Sends a list of subaccount ids that are potentially liquidatable.